@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001-2002 Zope Foundation and Contributors.
+# Copyright (c) 2001, 2002 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -48,7 +48,7 @@ The package has several public modules:
 
 See the module doc strings for more information.
 
-$Id: __init__.py 105433 2009-11-02 08:33:25Z ctheune $
+$Id$
 """
 __docformat__ = 'restructuredtext'
 
@@ -63,7 +63,8 @@ from zope.interface.interface import Attribute, invariant, taggedValue
 from zope.interface.declarations import providedBy, implementedBy
 from zope.interface.declarations import classImplements, classImplementsOnly
 from zope.interface.declarations import directlyProvidedBy, directlyProvides
-from zope.interface.declarations import alsoProvides, implementer
+from zope.interface.declarations import alsoProvides, provider
+from zope.interface.declarations import implementer, implementer_only
 from zope.interface.declarations import implements, implementsOnly
 from zope.interface.declarations import classProvides, moduleProvides
 from zope.interface.declarations import noLongerProvides, Declaration
