@@ -880,6 +880,12 @@ _lookup(lookup *self,
 {
   PyObject *result, *key, *cache;
 
+  if ( name && !PyString_Check(name) && !PyUnicode_Check(name) )
+  {
+    PyErr_SetString(PyExc_ValueError,
+                    "name is not a string or unicode");
+    return NULL;
+  }
   cache = _getcache(self, provided, name);
   if (cache == NULL)
     return NULL;
@@ -961,6 +967,13 @@ _lookup1(lookup *self,
 {
   PyObject *result, *cache;
 
+  if ( name && !PyString_Check(name) && !PyUnicode_Check(name) )
+  {
+    PyErr_SetString(PyExc_ValueError,
+                    "name is not a string or unicode");
+    return NULL;
+  }
+
   cache = _getcache(self, provided, name);
   if (cache == NULL)
     return NULL;
@@ -1018,6 +1031,13 @@ _adapter_hook(lookup *self,
 {
   PyObject *required, *factory, *result;
 
+  if ( name && !PyString_Check(name) && !PyUnicode_Check(name) )
+  {
+    PyErr_SetString(PyExc_ValueError,
+                    "name is not a string or unicode");
+    return NULL;
+  }
+
   required = providedBy(NULL, object);
   if (required == NULL)
     return NULL;
@@ -1565,7 +1585,8 @@ static struct PyMethodDef m_methods[] = {
 };
 
 #if  PY_MAJOR_VERSION >= 3
-static char module_doc[] = "C optimizations for zope.interface\n\n";
+static char module_doc[] = "C optimizations for zope.interface\n\n"
+  "$Id$";
 
 static struct PyModuleDef _zic_module = {
 	PyModuleDef_HEAD_INIT,
@@ -1580,6 +1601,9 @@ static struct PyModuleDef _zic_module = {
 };
 #endif
 
+#ifndef PyMODINIT_FUNC	/* declarations for DLL import/export */
+#define PyMODINIT_FUNC void
+#endif
 static PyObject *
 init(void)
 {
@@ -1642,7 +1666,8 @@ init(void)
   #if PY_MAJOR_VERSION < 3
   /* Create the module and add the functions */
   m = Py_InitModule3("_zope_interface_coptimizations", m_methods,
-                     "C optimizations for zope.interface\n\n");
+                     "C optimizations for zope.interface\n\n"
+                     "$Id$");
   #else
   m = PyModule_Create(&_zic_module);
   #endif
@@ -1668,8 +1693,8 @@ init(void)
   return m;
 }
 
-PyMODINIT_FUNC
 #if PY_MAJOR_VERSION < 3
+PyMODINIT_FUNC
 init_zope_interface_coptimizations(void)
 {
   init();
