@@ -1,10 +1,10 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -13,7 +13,7 @@
 ##############################################################################
 """Adapter management
 
-$Id: adapter.py 101362 2009-06-30 20:08:57Z fdrake $
+$Id$
 """
 
 import weakref
@@ -33,19 +33,19 @@ class BaseAdapterRegistry(object):
 
     def __init__(self, bases=()):
 
+        # The comments here could be improved. Possibly this bit needs
+        # explaining in a separate document, as the comments here can
+        # be quite confusing. /regebro
+
         # {order -> {required -> {provided -> {name -> value}}}}
-        # where "interfaces" is really a nested key.  So, for example:
-        # for order == 0, we have:
-        #   {provided -> {name -> valie}}
-        # but for order == 2, we have:
-        #   {r1 -> {r2 -> {provided -> {name -> valie}}}}
+        # Here "order" is actually an index in a list, "required" and
+        # "provided" are interfaces, and "required" is really a nested
+        # key.  So, for example:
+        # for order == 0 (that is, self._adapters[0]), we have:
+        #   {provided -> {name -> value}}
+        # but for order == 2 (that is, self._adapters[2]), we have:
+        #   {r1 -> {r2 -> {provided -> {name -> value}}}}
         #
-        # XXX ^^^ what does the above comment have to do with any code
-        # in this method?  and.. "interfaces is really a nested key"?
-        # i don't see "interfaces" mentioned.  does it mean
-        # "provided"?  what are r1 and r2?  why is the structure just
-        # below this a list?  is this comment 100% bitrotten or just a
-        # little? /XXX
         self._adapters = []
 
         # {order -> {required -> {provided -> {name -> [value]}}}}
@@ -56,26 +56,28 @@ class BaseAdapterRegistry(object):
         # for which we have provided components:
         self._provided = {}
 
-        # Looup object to perform lookup.  We make this a separate object to
-        # to make it easier, in the furture, to implement just the lookup
-        # functionality in C.
+        # Create ``_v_lookup`` object to perform lookup.  We make this a
+        # separate object to to make it easier to implement just the
+        # lookup functionality in C.  This object keeps track of cache
+        # invalidation data in two kinds of registries.
+
+        #   Invalidating registries have caches that are invalidated
+        #     when they or their base registies change.  An invalidating
+        #     registry can only have invalidating registries as bases.
+        #     See LookupBasePy below for the pertinent logic.
+
+        #   Verifying registies can't rely on getting invalidation messages,
+        #     so have to check the generations of base registries to determine
+        #     if their cache data are current.  See VerifyingBasePy below
+        #     for the pertinent object.
         self._createLookup()
 
-        # Cache invalidation data.  There are really 2 kinds of registries:
-        
-        #   Invalidating registries have caches that are invalidated
-        #     when they or when base registies change.  An invalidating
-        #     registry can only have invalidating registries as bases.
+        # Setting the bases causes the registries described above
+        # to be initialized (self._setBases -> self.changed ->
+        # self._v_lookup.changed).
 
-        #   Verifying registies can't rely on getting invalidation message,
-        #     so have to check the generations of base registries to determine
-        #     if their cache data are current
-
-        # ^^^ XXX what are the above comments describing? /XXX
-
-        # Base registries:
         self.__bases__ = bases
-        
+
     def _setBases(self, bases):
         self.__dict__['__bases__'] = bases
         self.ro = ro.ro(self)
@@ -95,6 +97,8 @@ class BaseAdapterRegistry(object):
         self._v_lookup.changed(originally_changed)
 
     def register(self, required, provided, name, value):
+        if not isinstance(name, basestring):
+            raise ValueError('name is not text')
         if value is None:
             self.unregister(required, provided, name, value)
             return
@@ -107,7 +111,7 @@ class BaseAdapterRegistry(object):
             byorder.append({})
         components = byorder[order]
         key = required + (provided,)
-        
+
         for k in key:
             d = components.get(k)
             if d is None:
@@ -117,7 +121,7 @@ class BaseAdapterRegistry(object):
 
         if components.get(name) is value:
             return
-        
+
         components[name] = value
 
         n = self._provided.get(provided, 0) + 1
@@ -137,7 +141,7 @@ class BaseAdapterRegistry(object):
 
         components = byorder[order]
         key = required + (provided,)
-        
+
         for k in key:
             d = components.get(k)
             if d is None:
@@ -145,7 +149,7 @@ class BaseAdapterRegistry(object):
             components = d
 
         return components.get(name)
-        
+
     def unregister(self, required, provided, name, value=None):
         required = tuple(map(_convert_None_to_Interface, required))
         order = len(required)
@@ -154,7 +158,9 @@ class BaseAdapterRegistry(object):
             return False
         components = byorder[order]
         key = required + (provided,)
-        
+
+        # Keep track of how we got to `components`:
+        lookups = []
         # Keep track of how we got to `components`:
         lookups = []
         for k in key:
@@ -203,7 +209,7 @@ class BaseAdapterRegistry(object):
             byorder.append({})
         components = byorder[order]
         key = required + (provided,)
-        
+
         for k in key:
             d = components.get(k)
             if d is None:
@@ -229,7 +235,9 @@ class BaseAdapterRegistry(object):
             return
         components = byorder[order]
         key = required + (provided,)
-        
+
+        # Keep track of how we got to `components`:
+        lookups = []
         # Keep track of how we got to `components`:
         lookups = []
         for k in key:
@@ -294,12 +302,12 @@ class LookupBasePy(object):
         self._cache = {}
         self._mcache = {}
         self._scache = {}
-        
+
     def changed(self, ignored=None):
         self._cache.clear()
         self._mcache.clear()
         self._scache.clear()
-        
+
     def _getcache(self, provided, name):
         cache = self._cache.get(provided)
         if cache is None:
@@ -314,6 +322,8 @@ class LookupBasePy(object):
         return cache
 
     def lookup(self, required, provided, name=u'', default=None):
+        if not isinstance(name, basestring):
+            raise ValueError('name is not text')
         cache = self._getcache(provided, name)
         if len(required) == 1:
             result = cache.get(required[0], _not_in_mapping)
@@ -331,8 +341,10 @@ class LookupBasePy(object):
             return default
 
         return result
-    
+
     def lookup1(self, required, provided, name=u'', default=None):
+        if not isinstance(name, basestring):
+            raise ValueError('name is not text')
         cache = self._getcache(provided, name)
         result = cache.get(required, _not_in_mapping)
         if result is _not_in_mapping:
@@ -347,6 +359,8 @@ class LookupBasePy(object):
         return self.adapter_hook(provided, object, name, default)
 
     def adapter_hook(self, provided, object, name=u'', default=None):
+        if not isinstance(name, basestring):
+            raise ValueError('name is not text')
         required = providedBy(object)
         cache = self._getcache(provided, name)
         factory = cache.get(required, _not_in_mapping)
@@ -388,7 +402,7 @@ class LookupBasePy(object):
             cache[required] = result
 
         return result
-    
+
 LookupBase = LookupBasePy
 
 class VerifyingBasePy(LookupBasePy):
@@ -406,7 +420,7 @@ class VerifyingBasePy(LookupBasePy):
     def _getcache(self, provided, name):
         self._verify()
         return LookupBasePy._getcache(self, provided, name)
-    
+
     def lookupAll(self, required, provided):
         self._verify()
         return LookupBasePy.lookupAll(self, required, provided)
@@ -463,7 +477,7 @@ class AdapterLookupBase(object):
     # TODO: add invalidation when a provided interface changes, in case
     # the interface's __iro__ has changed.  This is unlikely enough that
     # we'll take our chances for now.
-    
+
     def init_extendors(self):
         self._extendors = {}
         for p in self._registry._provided:
@@ -477,7 +491,7 @@ class AdapterLookupBase(object):
                 [e for e in extendors if provided.isOrExtends(e)]
                 +
                 [provided]
-                + 
+                +
                 [e for e in extendors if not provided.isOrExtends(e)]
                 )
 
@@ -527,7 +541,7 @@ class AdapterLookupBase(object):
         if result is None:
             return default
 
-        return result        
+        return result
 
     def _uncached_lookupAll(self, required, provided):
         order = len(required)
@@ -630,7 +644,7 @@ class VerifyingAdapterLookup(AdapterLookupBase, VerifyingBase):
 class VerifyingAdapterRegistry(BaseAdapterRegistry):
 
     LookupClass = VerifyingAdapterLookup
-    
+
 def _convert_None_to_Interface(x):
     if x is None:
         return Interface
@@ -658,7 +672,7 @@ def _lookup(components, specs, provided, name, i, l):
                 r = comps.get(name)
                 if r is not None:
                     return r
-                
+
     return None
 
 def _lookupAll(components, specs, provided, result, i, l):
