@@ -14,11 +14,11 @@
 This module is called idatetime because if it were called datetime the import
 of the real datetime would fail.
 
-$Id: idatetime.py 105433 2009-11-02 08:33:25Z ctheune $
+$Id$
 """
 
 from zope.interface import Interface, Attribute
-from zope.interface import classImplements, directlyProvides
+from zope.interface import classImplements
 
 from datetime import timedelta, date, datetime, time, tzinfo
 
