@@ -13,7 +13,7 @@
 ##############################################################################
 """Interface Package Interfaces
 
-$Id: interfaces.py 105433 2009-11-02 08:33:25Z ctheune $
+$Id$
 """
 __docformat__ = 'restructuredtext'
 
@@ -446,6 +446,13 @@ class IInterfaceDeclaration(Interface):
         Instances of ``C`` provide only ``I1``, ``I2``, and regardless of
         whatever interfaces instances of ``A`` and ``B`` implement.
         """
+        
+    def implementer_only(*interfaces):
+        """Create a decorator for declaring the only interfaces implemented 
+        
+        A callable is returned that makes an implements declaration on
+        objects passed to it.
+        """
 
     def directlyProvidedBy(object):
         """Return the interfaces directly provided by the given object
@@ -499,7 +506,7 @@ class IInterfaceDeclaration(Interface):
 
         is equivalent to::
 
-          directivelyProvides(ob, directlyProvidedBy(ob), I1)
+          directlyProvides(ob, directlyProvidedBy(ob), I1)
         """
 
     def noLongerProvides(object, interface):
@@ -614,6 +621,8 @@ class IInterfaceDeclaration(Interface):
 
         after the class has been created.
         """
+    def provider(*interfaces):
+        """A class decorator version of classProvides"""
 
     def moduleProvides(*interfaces):
         """Declare interfaces provided by a module
@@ -666,12 +675,14 @@ class IAdapterRegistry(Interface):
         """Register a value
 
         A value is registered for a *sequence* of required specifications, a
-        provided interface, and a name.
+        provided interface, and a name, which must be text.
         """
 
     def registered(required, provided, name=u''):
         """Return the component registered for the given interfaces and name
 
+        name must be text.
+
         Unlike the lookup method, this methods won't retrieve
         components registered for more specific required interfaces or
         less specific provided interfaces.
@@ -685,7 +696,8 @@ class IAdapterRegistry(Interface):
         """Lookup a value
 
         A value is looked up based on a *sequence* of required
-        specifications, a provided interface, and a name.
+        specifications, a provided interface, and a name, which must be
+        text.
         """
 
     def queryMultiAdapter(objects, provided, name=u'', default=None):
@@ -696,7 +708,8 @@ class IAdapterRegistry(Interface):
         """Lookup a value using a single required interface
 
         A value is looked up based on a single required
-        specifications, a provided interface, and a name.
+        specifications, a provided interface, and a name, which must be
+        text.
         """
 
     def queryAdapter(object, provided, name=u'', default=None):
@@ -705,6 +718,8 @@ class IAdapterRegistry(Interface):
 
     def adapter_hook(provided, object, name=u'', default=None):
         """Adapt an object using a registered adapter factory.
+
+        name must be text.
         """
 
     def lookupAll(required, provided):
