@@ -13,12 +13,12 @@
 ##############################################################################
 """Adapter registry tests
 
-$Id: test_adapter.py 105433 2009-11-02 08:33:25Z ctheune $
+$Id$
 """
+import doctest
 import unittest
 import zope.interface
 from zope.interface.adapter import AdapterRegistry
-import zope.interface
 
 
 class IF0(zope.interface.Interface):
@@ -134,6 +134,11 @@ def test_named_adapter_with_default():
     If we ask for a named adapter, we won't get a result unless there
     is a named adapter, even if the object implements the interface:
 
+    >>> registry.lookup([IF1], IF0, None) #doctest: +ELLIPSIS
+    Traceback (most recent call last):
+    ...
+    ValueError: name...
+
     >>> registry.lookup([IF1], IF0, 'bob')
 
     >>> registry.register([None], IB1, 'bob', 'A1')
@@ -402,9 +407,8 @@ def test_unsubscribe_cleans_up_empties():
 
 
 def test_suite():
-    from zope.testing import doctest, doctestunit
     return unittest.TestSuite((
-        doctestunit.DocFileSuite('../adapter.txt', '../adapter.ru.txt',
+        doctest.DocFileSuite('../adapter.txt', '../adapter.ru.txt',
                                  '../human.txt', '../human.ru.txt',
                                  'foodforthought.txt',
                                  globs={'__name__': '__main__'}),
