@@ -24,6 +24,8 @@ PEAK is a Python application framework that interoperates with (but does
 not require) Zope 3 and Twisted.  It provides tools for manipulating UML
 models, object-relational persistence, aspect-oriented programming, and more.
 Visit the PEAK home page at http://peak.telecommunity.com for more information.
+
+$Id$
 """
 
 import unittest
@@ -179,7 +181,7 @@ def test_suite():
         return TestSuite([makeSuite(t,'check') for t in TestClasses])
     else:
         # Advise metaclasses doesn't work in Python 3
-        return TestSuite([])
+        return []
 
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
