@@ -15,6 +15,8 @@
 
 These tests are to make sure we do something sane in the presence of
 classic ExtensionClass classes and instances.
+
+$Id$
 """
 import doctest
 import unittest
@@ -177,17 +179,6 @@ class Test(unittest.TestCase):
     def test_directlyProvides_fails_for_odd_class(self):
         self.assertRaises(TypeError, directlyProvides, C, I5)
 
-    # see above
-    def TODO_test_classProvides_fails_for_odd_class(self):
-        try:
-            class A(Odd):
-                classProvides(I1)
-        except TypeError:
-            pass # Sucess
-        self.assert_(False,
-                     "Shouldn't be able to use directlyProvides on odd class."
-                     )
-
     def test_implementedBy(self):
         class I2(I1): pass
 
